@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -29,6 +29,7 @@ from __future__ import unicode_literals, absolute_import
 import os
 # import re
 import datetime
+import decimal
 import os
 import shutil
 import socket
@@ -104,6 +105,35 @@ class AppHandler(object):
         """
         return self.config.app_title(default=default)
 
+    def get_class_prefix(self, default=None):
+        """
+        Returns the "class prefix" for the app, used when naming model
+        classes etc.
+        """
+        prefix = self.config.get('rattail', 'app_class_prefix',
+                                 default=default)
+        if prefix:
+            return prefix
+
+        title = self.get_title(default="Rattail")
+        prefix = title.replace(' ', '')
+        return prefix
+
+    def get_table_prefix(self, default=None):
+        """
+        Returns the "table prefix" for the app, used when naming
+        tables etc.
+        """
+        prefix = self.config.get('rattail', 'app_table_prefix',
+                                 default=default)
+        if prefix:
+            return prefix
+
+        title = self.get_title(default="Rattail")
+        prefix = title.lower()\
+                      .replace(' ', '_')
+        return prefix
+
     def get_timezone(self, key='default'):
         """
         Returns a configured time zone.
@@ -118,6 +148,33 @@ class AppHandler(object):
         from rattail.time import timezone
         return timezone(self.config, key)
 
+    def json_friendly(self, value):
+        """
+        Coerce a Python value to one which is JSON-serializable.
+
+        So, this does *not* return a JSON string, but rather a Python
+        object which can then be safely converted via
+        ``json.dumps()``.
+
+        If the value is a container, it will be crawled recursively
+        and all values it contains will be coerced.
+        """
+        if isinstance(value, dict):
+            for key, val in six.iteritems(value):
+                value[key] = self.json_friendly(val)
+
+        elif isinstance(value, list):
+            for i in range(len(value)):
+                value[i] = self.json_friendly(value[i])
+
+        elif isinstance(value, decimal.Decimal):
+            value = float(value)
+
+        elif isinstance(value, datetime.datetime):
+            value = six.text_type(value)
+
+        return value
+
     def localtime(self, *args, **kwargs):
         """
         Produce or convert a timestamp in the default time zone.
@@ -540,6 +597,20 @@ class AppHandler(object):
 
         return self.bounce_handlers[key]
 
+    def get_cleanup_handler(self, **kwargs):
+        """
+        Get the configured "cleanup" handler.
+
+        :returns: The :class:`~rattail.cleanup.CleanupHandler`
+           instance for the app.
+        """
+        if not hasattr(self, 'cleanup_handler'):
+            spec = self.config.get('rattail.cleanup', 'handler',
+                                   default='rattail.cleanup:CleanupHandler')
+            Handler = self.load_object(spec)
+            self.cleanup_handler = Handler(self.config)
+        return self.cleanup_handler
+
     def get_clientele_handler(self, **kwargs):
         """
         Get the configured "clientele" handler.
@@ -581,6 +652,20 @@ class AppHandler(object):
             self.datasync_handler = Handler(self.config, **kwargs)
         return self.datasync_handler
 
+    def get_db_handler(self, **kwargs):
+        """
+        Get the configured "database" handler.
+
+        :returns: The :class:`~rattail.db.handler.DatabaseHandler`
+           instance for the app.
+        """
+        if not hasattr(self, 'db_handler'):
+            spec = self.config.get('rattail.db', 'handler',
+                                   default='rattail.db.handler:DatabaseHandler')
+            Handler = self.load_object(spec)
+            self.db_handler = Handler(self.config)
+        return self.db_handler
+
     def get_employment_handler(self, **kwargs):
         """
         Get the configured "employment" handler.
@@ -1048,6 +1133,7 @@ class AppHandler(object):
 
     def short_session(self, **kwargs):
         from rattail.db.util import short_session
+        kwargs.setdefault('factory', self.make_session)
         return short_session(**kwargs)
 
     def cache_model(self, session, model, **kwargs):
