@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -57,6 +57,10 @@ class CustomerOrderBatchHandler(BatchHandler):
     has_custom_product_autocomplete = False
     nondigits_pattern = re.compile(r'\D')
 
+    def __init__(self, config, **kwargs):
+        super(CustomerOrderBatchHandler, self).__init__(config, **kwargs)
+        self.custorder_handler = self.app.get_custorder_handler()
+
     def init_batch(self, batch, progress=None, **kwargs):
         """
         Assign the "local" store to the batch, if applicable.
@@ -134,6 +138,15 @@ class CustomerOrderBatchHandler(BatchHandler):
                                    'allow_item_discounts',
                                    default=False)
 
+    def allow_item_discounts_if_on_sale(self):
+        """
+        Returns boolean indicating whether per-item discounts are
+        allowed when item is already on sale.
+        """
+        return self.config.getbool('rattail.custorders',
+                                   'allow_item_discounts_if_on_sale',
+                                   default=False)
+
     def allow_past_item_reorder(self):
         """
         Returns boolean indicating whether to expose past items for
@@ -518,6 +531,7 @@ class CustomerOrderBatchHandler(BatchHandler):
             'url': products.get_url(product),
             'image_url': products.get_image_url(product),
             'uom_choices': self.uom_choices_for_product(product),
+            'default_item_discount': self.get_default_item_discount(product),
         }
 
         # TODO: this was somewhat copied from
@@ -605,6 +619,14 @@ class CustomerOrderBatchHandler(BatchHandler):
            return that reason as a string; otherwise ``None``.
         """
 
+    def get_default_item_discount(self, product=None, **kwargs):
+        """
+        Returns default item discount available.  If product is given,
+        the default may be specific to its department etc.
+        """
+        return self.custorder_handler.get_default_item_discount(
+            product=product, **kwargs)
+
     def add_product(self, batch, product, order_quantity, order_uom,
                     **kwargs):
         """
