@@ -306,9 +306,9 @@ class VendorCatalogHandler(BatchHandler):
         if row.unit_cost is not None and row.old_unit_cost is not None:
             row.unit_cost_diff = row.unit_cost - row.old_unit_cost
             if row.old_unit_cost:
-                row.unit_cost_diff_percent = row.unit_cost_diff / row.old_unit_cost
+                row.unit_cost_diff_percent = 100 * row.unit_cost_diff / row.old_unit_cost
             else:
-                row.unit_cost_diff_percent = 1
+                row.unit_cost_diff_percent = 100
 
     def set_status_per_diffs(self, row):
 
