@@ -160,6 +160,11 @@ class VendorInvoiceHandler(BatchHandler):
         row.description = product.description
         row.size = product.size
 
+        # fetch case size from product master, if invoice didn't provide
+        if not row.case_quantity:
+            products_handler = self.app.get_products_handler()
+            row.case_quantity = products_handler.get_case_size(product)
+
         # Calculate case cost if the parser couldn't provide one.
         if not row.case_cost and row.unit_cost and row.case_quantity:
             row.case_cost = row.unit_cost * row.case_quantity
