@@ -29,10 +29,12 @@ from __future__ import unicode_literals, absolute_import
 import os
 import datetime
 import logging
+import sys
 
 from rattail.commands.core import Subcommand, date_argument, dict_argument
 from rattail.progress import SocketProgress
 from rattail.time import localtime, make_utc
+from rattail.util import simple_error
 
 
 log = logging.getLogger(__name__)
@@ -41,6 +43,12 @@ log = logging.getLogger(__name__)
 class BatchHandlerCommand(Subcommand):
     """
     Base class for commands which invoke a batch handler.
+
+    Note that if such a command fails to run its action, the error
+    will be written to STDOUT as a simple message string.  If the full
+    traceback is needed, logs must be consulted.  This is done for
+    sake of letting the caller capture output for display to the user
+    when something goes wrong.
     """
 
     def add_parser_args(self, parser):
@@ -76,7 +84,21 @@ class BatchHandlerCommand(Subcommand):
         session = self.make_session()
         user = self.get_runas_user(session)
 
-        success = self.do_stuff(args, handler, session, user)
+        try:
+            success = self.do_stuff(args, handler, session, user)
+        except Exception as error:
+            log.warning("handler action failed", exc_info=True)
+            # nb. only write "simple" error string to stdout, in case
+            # caller (e.g. web app) is capturing that for display to
+            # user.  admin can consult logs if more info is needed.
+            # we do *not* write to stderr, because logging probably
+            # is already doing that; we want to avoid mixing them.
+            # TODO: this admittedly seems brittle, maybe caller should
+            # pass command line flags to control this?
+            self.stdout.write(simple_error(error))
+            session.rollback()
+            session.close()
+            sys.exit(42)
 
         if args.dry_run:
             session.rollback()
