@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,7 +21,9 @@
 #
 ################################################################################
 """
-DataSync Daemon
+This subpackage contains logic for the Rattail "datasync" daemon.
+
+For general info see :doc:`rattail-manual:data/sync/index`.
 """
 
 from __future__ import unicode_literals, absolute_import
