@@ -27,7 +27,8 @@ def upgrade():
     op.add_column('product', sa.Column('special_order', sa.Boolean(), nullable=True))
     product = sa.sql.table('product', sa.sql.column('special_order'))
     op.execute(product.update().values({'special_order': False}))
-    op.alter_column('product', 'special_order', nullable=False)
+    op.alter_column('product', 'special_order', nullable=False,
+                    existing_type=sa.Boolean())
     op.add_column('product_version', sa.Column('special_order', sa.Boolean(), nullable=True))
 
 
