@@ -165,4 +165,4 @@ class WorkedShift(Base, ShiftMixin):
     end_time = orm.synonym('punch_out')
 
     def __str__(self):
-        return unicode(self.employee or '')
+        return str(self.employee or '')
