@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -123,10 +123,14 @@ class ToFile(Importer):
         if not hasattr(self, 'output_file_path'):
             filename = self.get_output_filename()
             self.output_file_path = os.path.join(self.handler.output_dir, filename)
-        self.open_output_file()
+        if not self.dry_run:
+            self.open_output_file()
 
     def teardown(self):
-        self.close_output_file()
+        super(ToFile, self).teardown()
+
+        if not self.dry_run:
+            self.close_output_file()
 
     def get_output_filename(self):
         """
@@ -188,7 +192,8 @@ class ToCSV(ToFile):
         Add objects's record to CSV output file.
         """
         data = self.coerce_csv(data)
-        self.output_writer.writerow(data)
+        if not self.dry_run:
+            self.output_writer.writerow(data)
         return data
 
     def coerce_csv(self, data):
