@@ -526,15 +526,20 @@ class Importer(object):
         normalized = []
 
         def normalize(obj, i):
-            data = self.normalize_host_object(obj)
+            data = self.normalize_host_object_all(obj)
             if data:
-                normalized.append(data)
+                normalized.extend(data)
 
         self.progress_loop(normalize, host_objects,
                            message="Reading {} data from {}".format(
                                self.model_name, self.host_system_title))
         return normalized
 
+    def normalize_host_object_all(self, obj):
+        data = self.normalize_host_object(obj)
+        if data:
+            return [data]
+
     def normalize_host_object(self, obj):
         """
         Normalize a raw host object into a data dict, or return ``None`` if the
