@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -153,6 +153,15 @@ class ProductsHandler(GenericHandler, MergeMixin):
         # no check digits needed
         return False
 
+    def units_only(self):
+        """
+        Returns boolean indicating whether products are "unit only".
+        So if this returns ``False`` (the default) then products are
+        expected to have case size also.
+        """
+        return self.config.getbool('rattail', 'products.units_only',
+                                   default=False)
+
     # TODO: deprecate / remove (afaik it is not being used?)
     def find_products_by_key(self, session, value, **kwargs):
         """
@@ -643,6 +652,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
             'product_key': self.render_product_key(product),
             'description': product.description,
             'size': product.size,
+            '_str': six.text_type(product),
         }
 
         if not fields:
@@ -674,13 +684,26 @@ class ProductsHandler(GenericHandler, MergeMixin):
             vendor = product.cost.vendor if product.cost else None
             data['vendor_name'] = vendor.name if vendor else None
 
+        if 'costs' in fields:
+            costs = []
+            for cost in product.costs:
+                costs.append({
+                    'uuid': cost.uuid,
+                    'vendor_uuid': cost.vendor_uuid,
+                    'vendor_name': cost.vendor.name,
+                    'preference': cost.preference,
+                    'code': cost.code,
+                    'case_size': cost.case_size,
+                    'case_cost': cost.case_cost,
+                    'unit_cost': cost.unit_cost,
+                })
+            data['costs'] = costs
+
         sale_fields = [
             'sale_price',
             'sale_price_display',
             'sale_ends',
             'sale_ends_display',
-            'case_price',
-            'case_price_display',
         ]
         if any([f in fields for f in sale_fields]):
             sale_price = None
