@@ -28,6 +28,7 @@ from __future__ import unicode_literals, absolute_import
 
 import os
 import random
+import re
 import shutil
 import string
 import subprocess
@@ -287,6 +288,9 @@ class RattailProjectHandler(ProjectHandler):
         """
         And here we do some experimentation...
         """
+        from alembic.config import Config as AlembicConfig
+        from alembic.command import revision as alembic_revision
+
         context = options
 
         ##############################
@@ -329,8 +333,6 @@ class RattailProjectHandler(ProjectHandler):
         self.generate('rattail/package/emails.py.mako', os.path.join(package, 'emails.py'),
                       **context)
 
-        self.generate('rattail/package/settings.py', os.path.join(package, 'settings.py'))
-
         ##############################
         # data dir
         ##############################
@@ -380,17 +382,56 @@ class RattailProjectHandler(ProjectHandler):
             alembic = os.path.join(db, 'alembic')
             os.makedirs(alembic)
 
-            self.generate('rattail/package/db/alembic/README', os.path.join(alembic, 'README'))
-
             self.generate('rattail/package/db/alembic/env.py.mako', os.path.join(alembic, 'env.py'),
                           **context)
 
-            self.generate('rattail/package/db/alembic/script.py.mako_', os.path.join(alembic, 'script.py.mako'))
-
             versions = os.path.join(alembic, 'versions')
             os.makedirs(versions)
 
-            self.generate('rattail/package/db/alembic/versions/.keepme', os.path.join(versions, '.keepme'))
+            # make alembic config, aware of new project versions folder
+            alembic_config = AlembicConfig()
+            alembic_config.set_main_option('script_location',
+                                        'rattail.db:alembic')
+            alembic_config.set_main_option('version_locations',
+                                        '{} rattail.db:alembic/versions'.format(
+                                            versions))
+
+            # generate first revision script for new project
+            script = alembic_revision(alembic_config,
+                                      version_path=versions,
+                                      head='rattail@head',
+                                      splice=True,
+                                      branch_label=context['python_name'],
+                                      message="add {} branch".format(context['python_name']))
+
+            # declare `down_revision = None` ..no way to tell alembic
+            # to do that apparently, so we must rewrite file
+            with open(script.path, 'rt') as f:
+                old_contents = f.read()
+            new_contents = []
+            for line in old_contents.split('\n'):
+                if line.startswith('down_revision ='):
+                    line = re.sub(r"'\w+'", 'None', line)
+                new_contents.append(line)
+            with open(script.path, 'wt') as f:
+                f.write('\n'.join(new_contents))
+
+        ##############################
+        # templates
+        ##############################
+
+        templates = os.path.join(package, 'templates')
+        os.makedirs(templates)
+
+        installer = os.path.join(templates, 'installer')
+        os.makedirs(installer)
+
+        self.generate('rattail/package/templates/installer/rattail.conf.mako_tmpl',
+                      os.path.join(installer, 'rattail.conf.mako'),
+                      **context)
+
+        self.generate('rattail/package/templates/installer/upgrade.sh.mako_',
+                      os.path.join(installer, 'upgrade.sh.mako'))
 
         ##############################
         # web package dir
@@ -418,10 +459,11 @@ class RattailProjectHandler(ProjectHandler):
             self.generate('rattail/package/web/static/__init__.py.mako', os.path.join(static, '__init__.py'),
                           **context)
 
-            templates = os.path.join(web, 'templates')
-            os.makedirs(templates)
+            web_templates = os.path.join(web, 'templates')
+            os.makedirs(web_templates)
 
-            self.generate('rattail/package/web/templates/base_meta.mako_tmpl', os.path.join(templates, 'base_meta.mako'),
+            self.generate('rattail/package/web/templates/base_meta.mako_tmpl',
+                          os.path.join(web_templates, 'base_meta.mako'),
                           **context)
 
             views = os.path.join(web, 'views')
@@ -697,12 +739,14 @@ class RattailProjectHandler(ProjectHandler):
         # static
         ##############################
 
-        static = os.path.join(package, 'static')
-        os.makedirs(static)
+        if options['has_static_files']:
 
-        self.generate('tailbone_integration/package/static/__init__.py.mako',
-                      os.path.join(static, '__init__.py'),
-                      **context)
+            static = os.path.join(package, 'static')
+            os.makedirs(static)
+
+            self.generate('tailbone_integration/package/static/__init__.py.mako',
+                          os.path.join(static, '__init__.py'),
+                          **context)
 
         ##############################
         # templates
