@@ -27,6 +27,8 @@ Utilities
 from __future__ import unicode_literals, absolute_import
 from __future__ import division
 
+import re
+import shlex
 import sys
 import datetime
 import decimal
@@ -364,3 +366,37 @@ def simple_error(error):
     if msg:
         return "{}: {}".format(cls, msg)
     return cls
+
+
+def shlex_join(split_command):
+    """
+    Wrapper which invokes ``shlex.join()`` if available; otherwise
+    a workaround is implemented.
+
+    cf. https://stackoverflow.com/a/50022816
+    """
+    # python 3.8+ has native shlex.join()
+    if hasattr(shlex, 'join'):
+        return shlex.join(split_command)
+
+    # python 3.3+ has native shlex.quote()
+    if hasattr(shlex, 'quote'):
+        return ' '.join(shlex.quote(x) for x in split_command)
+
+    # python 2 has neither...so the rest of this logic is copy/pasted
+    # from later python
+    # _find_unsafe = re.compile(r'[^\w@%+=:,./-]', re.ASCII).search
+    _find_unsafe = re.compile(r'[^\w@%+=:,./-]').search
+
+    def quote(s):
+        """Return a shell-escaped version of the string *s*."""
+        if not s:
+            return "''"
+        if _find_unsafe(s) is None:
+            return s
+
+        # use single quotes, and put single quotes into double quotes
+        # the string $'b is then quoted as '$'"'"'b'
+        return "'" + s.replace("'", "'\"'\"'") + "'"
+
+    return ' '.join(quote(x) for x in split_command)
