@@ -28,6 +28,8 @@ from __future__ import unicode_literals, absolute_import
 
 import six
 
+from sqlalchemy import orm
+
 from rattail.app import GenericHandler
 from rattail.util import load_entry_points
 
@@ -76,9 +78,33 @@ class VendorHandler(GenericHandler):
         This is mainly useful to allow catalog and invoice parsers to
         "loosely" associate with a particular vendor by way of this
         key, which could be shared across organizations etc.
+
+        :param session: Active database session.
+
+        :param key: Value to use when searching for the vendor.
+
+        :returns: The :class:`~rattail.db.model.vendors.Vendor`
+           instance if found; otherwise ``None``.
         """
-        from rattail.db.api.vendors import get_vendor
-        return get_vendor(session, key)
+        model = self.model
+
+        # Vendor.uuid match?
+        vendor = session.query(model.Vendor).get(key)
+        if vendor:
+            return vendor
+
+        # Vendor.id match?
+        try:
+            return session.query(model.Vendor)\
+                          .filter(model.Vendor.id == key)\
+                          .one()
+        except orm.exc.NoResultFound:
+            pass
+
+        # try settings, if value then recurse
+        key = self.app.get_setting(session, 'rattail.vendor.{}'.format(key))
+        if key is not None:
+            return self.get_vendor(session, key, **kwargs)
 
     def render_vendor(self, vendor, **kwargs):
         return six.text_type(vendor)
