@@ -71,11 +71,9 @@ class InvoiceParser(object):
         Fetch the :class:~rattail.db.model.vendors.Vendor` record
         which is associated with the current parser, if any.
         """
-        from rattail.db import api
-
         if self.vendor_key:
-            vendor = api.get_vendor(session, self.vendor_key)
-            return vendor
+            vendor_handler = self.app.get_vendor_handler()
+            return vendor_handler.get_vendor(session, self.vendor_key)
 
     def parse_invoice_date(self, path):
         """
